@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -63,7 +63,7 @@ sub show_window {
     $window->set_position( 'mouse' );
 
     my $hb = Gtk3::HeaderBar->new;
-    $hb->set_title( _( 'Schedule' ) );
+    $hb->set_title( _( 'Analysis' ) );
     $hb->set_show_close_button( TRUE );
     $hb->set_decoration_layout( 'menu:close' );
 
@@ -79,6 +79,25 @@ sub show_window {
     $hb->pack_start( $button );
     $window->set_titlebar( $hb );
 
+    my $help_message = _(
+        "This section allows you to check the status of a file from Virustotal. If a file has been previously submitted, you will see the results of the scans from dozens of antivirus and security vendors. This allows you to make a more informed decision about the safety of a file.
+
+If the file has never been submitted to Virustotal, you can submit it yourself. When you resubmit the file minutes later, you should see the results.
+
+Please note you should never submit sensitive files to Virustotal.  Any uploaded file can be viewed by Virustotal customers. Do not submit anything with personal information or passwords.
+
+https://www.virustotal.com/gui/home/search"
+    );
+
+    my $help_btn  = Gtk3::ToolButton->new();
+    my $use_image = ClamTk::Icons->get_image( 'system-help' );
+    $help_btn->set_label( _( 'Help' ) );
+    $help_btn->set_icon_name( $use_image );
+    $help_btn->set_is_important( TRUE );
+    $help_btn->set_tooltip_text( _( 'What is this?' ) );
+    $help_btn->signal_connect( clicked => sub { popup( $help_message ) } );
+    $hb->pack_start( $help_btn );
+
     my $box = Gtk3::Box->new( 'vertical', 5 );
     $box->set_homogeneous( FALSE );
     $window->get_content_area->add( $box );
@@ -105,7 +124,8 @@ sub show_window {
     $bar = Gtk3::InfoBar->new;
     $box->pack_start( $bar, FALSE, FALSE, 0 );
     $bar->set_message_type( 'other' );
-    $bar->add_button( 'gtk-close', -7 );
+    # $bar->add_button( 'gtk-close', -7 );
+    $bar->add_button( _( 'Close' ), -7 );
     $bar->signal_connect(
         response => sub {
             $submitted = 0;
@@ -198,8 +218,10 @@ sub page_two {
     $separator->set_expand( TRUE );
     $toolbar->insert( $separator, -1 );
 
-    my $button = Gtk3::ToolButton->new_from_stock( 'gtk-save-as' );
-    $button->set_tooltip_text( _( 'Save results' ) );
+    my $button = Gtk3::ToolButton->new();
+    $button->set_icon_name( 'document-save-as' );
+    $button->set_label( _( 'Save results' ) );
+    # $button->set_tooltip_text( _( 'Save results' ) );
     $toolbar->insert( $button, -1 );
     $button->signal_connect(
         clicked => sub {
@@ -229,7 +251,9 @@ sub analysis_frame_one {
 
     #<<<
     # Declaring this now for setting sensitive/insensitive
-    my $button = Gtk3::ToolButton->new_from_stock( 'gtk-find' );
+    my $button = Gtk3::ToolButton->new();
+    my $use_image = ClamTk::Icons->get_image('edit-select');
+    $button->set_icon_name($use_image);
 
     my $select_button
         = Gtk3::FileChooserButton->new(
@@ -267,7 +291,7 @@ sub analysis_frame_one {
             # VT size limit using the API is 32MB
             # https://www.virustotal.com/en/faq/
             my $size = -s $filename;
-            my $mb = $size / ( 1024 * 1024 );
+            my $mb   = $size / ( 1024 * 1024 );
             if ( $mb > 32 ) {
                 warn "filesize too large - must be smaller than 32MB\n";
                 popup( _( 'Uploaded files must be smaller than 32MB' ) );
@@ -335,9 +359,10 @@ sub analysis_frame_two {
     $separator->set_draw( FALSE );
     $grid->attach( $separator, 1, 0, 1, 1 );
 
-    my $button = Gtk3::ToolButton->new_from_stock( 'gtk-index' );
-    $grid->attach( $button, 2, 0, 1, 1 );
+    my $button = Gtk3::ToolButton->new();
+    $button->set_icon_name( 'text-x-preview' );
     $button->set_tooltip_text( _( 'View file results' ) );
+    $grid->attach( $button, 2, 0, 1, 1 );
     $button->signal_connect(
         clicked => sub {
             # my $file = $combobox->get_active_text;
@@ -358,12 +383,12 @@ sub analysis_frame_two {
             # For some reason, we'll use csv files
             my $csv = Text::CSV->new( { binary => 1, eol => "\n" } )
                 or do {
-                warn "unable to begin Text::CSV: $!\n";
+                warn "Unable to begin Text::CSV: $!\n";
                 return;
                 };
 
             open( my $f, '<:encoding(utf8)', $file_to_use ) or do {
-                warn "unable to opening VT CSV file: $!\n";
+                warn "Unable to opening VT CSV file: $!\n";
                 # popup( _( 'Error opening VT CSV file' ) );
                 return;
             };
@@ -399,9 +424,10 @@ sub analysis_frame_two {
         }
     );
 
-    $button = Gtk3::ToolButton->new_from_stock( 'gtk-delete' );
-    $grid->attach( $button, 3, 0, 1, 1 );
+    $button = Gtk3::ToolButton->new();
+    $button->set_icon_name( 'edit-delete' );
     $button->set_tooltip_text( _( 'Delete file results' ) );
+    $grid->attach( $button, 3, 0, 1, 1 );
     $button->signal_connect(
         clicked => sub {
             my $file = $combobox->get_active_text;
@@ -418,7 +444,7 @@ sub analysis_frame_two {
                     $file_to_use = $key->{ readpath };
                     if ( -e $file_to_use ) {
                         unlink( $file_to_use ) or do {
-                            warn "unable to delete VT $file_to_use: $!\n";
+                            warn "Unable to delete VT $file_to_use: $!\n";
                             return;
                         };
                         $combobox->set_active( -1 );
@@ -450,7 +476,7 @@ sub read_files {
         $results->[ $arr_count ]->{ readpath } = $f;
         $results->[ $arr_count ]->{ hash }     = basename( $f );
         open( my $t, '<:encoding(utf8)', $f ) or do {
-            warn "unable to open analysis file >$f<: $!\n";
+            warn "Unable to open analysis file >$f<: $!\n";
             next;
         };
         while ( <$t> ) {
@@ -602,7 +628,7 @@ sub submit_new {
         my $json_hash = decode_json( $json_text );
 
         open( my $f, '>>:encoding(UTF-8)', $file );
-        # or warn "unable to save virustotal results: $!\n";
+        # or warn "Unable to save virustotal results: $!\n";
         my $csv = Text::CSV->new( { binary => 1, eol => "\n" } );
         my $ref;
         $ref->[ 0 ] = [ $filename, $hash, $json_hash->{ permalink } ];
@@ -637,7 +663,7 @@ sub get_hash {
     my $slurp = do {
         local $/ = undef;
         open( my $f, '<', $file ) or do {
-            warn "unable to open >$file< for hashing: $!\n";
+            warn "Unable to open >$file< for hashing: $!\n";
             return;
         };
         binmode( $f );
