@@ -117,7 +117,7 @@ sub structure {
     # This is /home/user/.clamtk/restore, which holds
     # information for putting back false positives
     if ( !-e $paths->{ restore } ) {
-        warn "restore does not exist; re-creating it\n";
+        # warn "restore does not exist; re-creating it\n";
         open( my $F, '>:encoding(UTF-8)', $paths->{ restore } )
             or do {
             warn "Unable to create restore file! $!\n";
@@ -202,6 +202,11 @@ sub custom_prefs {
         }
     }
 
+    # dtformat - for date-time-format
+    # if ( !exists $pkg{ 'dtformat' } ) {
+    #     $pkg{ 'dtformat' } = '%m %d %Y';
+    # }
+
     write_all( %pkg );
     return;
 }
