@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -165,9 +165,14 @@ sub filter {
     $box->pack_start( $bottombar, FALSE, FALSE, 5 );
 
     $bottombar->set_message_type( 'other' );
-    $bottombar->add_button( 'gtk-cancel', HATE_GNOME_SHELL );
+    # Stupid infobars
+    # $use_image = ClamTk::Icons->get_image( 'gtk-cancel' );
+    $use_image = 'gtk-cancel';
+    $bottombar->add_button( $use_image, HATE_GNOME_SHELL );
     if ( $show ) {
-        $bottombar->add_button( 'gtk-preferences', DESTROY_GNOME_SHELL );
+        # $use_image = ClamTk::Icons->get_image( 'preferences-system' );
+        $use_image = ClamTk::Icons->get_image( 'document-properties' );
+        $bottombar->add_button( $use_image, DESTROY_GNOME_SHELL );
     }
     $bottombar->signal_connect(
         response => sub {
@@ -212,7 +217,6 @@ sub filter {
             'smb4k',
             "/run/user/$ENV{USER}/gvfs",
             "$ENV{HOME}/.gvfs" ) {
-                # warn "excluding $m\n";
                 $directive .= " --exclude-dir=$m";
     }
     #>>>
@@ -235,14 +239,13 @@ sub filter {
         $directive .= " --exclude-dir=^" . quotemeta( $ignore );
     }
 
-    # Remove mail directories for now -
-    # until we can parse them... sigh.
+    # Remove mail directories and some backup directories for now.
     # Not all of these can be appended to $HOME for a more
     # specific path - kmail (e.g.) is somewhere
     # under $HOME/.kde/blah/foo/...
     my @maildirs = qw(
         .thunderbird	.mozilla-thunderbird
-        Mail	kmail   evolution
+        Mail	kmail   evolution   timeshift
     );
     for my $mailbox ( @maildirs ) {
         # warn "excluding mailbox directory $mailbox\n";
@@ -285,10 +288,8 @@ sub filter {
         if (   ( $version <=> '101' ) == 0
             || ( $version <=> '101' ) == 1 )
         {
-            $directive
-                .= ' --detect-pua --alert-broken'
-                . ' --alert-macros --alert-encrypted-archive'
-                . ' --alert-encrypted-doc --heuristic-alerts';
+            $directive .= ' --detect-pua --alert-broken'
+            . ' --alert-macros';
         } else {
             $directive .= ' --detect-pua --algorithmic-detection';
         }
@@ -296,13 +297,19 @@ sub filter {
         if (   ( $version cmp '101' ) == 0
             || ( $version cmp '101' ) == 1 )
         {
-            $directive
-                =~ s/\s--detect-pua --alert-broken --alert-macros --alert-encrypted-archive --alert-encrypted-doc --heuristic-alerts'//;
+            $directive =~ s/\s--detect-pua --alert-broken --alert-macros'//;
         } else {
             $directive =~ s/\s--detect-pua --algorithmic-detection//;
         }
     }
-    # print "directive = >", $directive, "<\n";
+
+    # Heuristic scanning
+    if ( $prefs{ Heuristic } ) {
+        # By default, if included, == yes
+        $directive .= ' --heuristic-alerts=yes';
+    } else {
+        $directive .= ' --heuristic-alerts=no';
+    }
 
     # only a single file
 
@@ -453,19 +460,13 @@ sub scan {
         # These aren't necessarily clean (despite the variable's name)
         # - we just don't want them counted as viruses
         my $clean_words = join( '|',
-            'OK',
-            'Zip module failure',
-            "RAR module failure",
-            'Encrypted.RAR',
-            'Encrypted.Zip',
-            'Empty file',
-            'Excluded',
-            'Input/Output error',
-            'Files number limit exceeded',
-            'handler error',
-            'Broken.Executable',
-            'Oversized.Zip',
-            'Symbolic link' );
+            'OK',                 'Zip module failure',
+            "RAR module failure", 'Encrypted.PDF',
+            'Encrypted.RAR',      'Encrypted.Zip',
+            'Empty file',         'Excluded',
+            'Input/Output error', 'Files number limit exceeded',
+            'handler error',      'Broken.Executable',
+            'Oversized.Zip',      'Symbolic link' );
 
         if ( $status !~ /$clean_words/ ) {    # a virus
             $found->{ $found_count }->{ name }   = $file;
