@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -100,22 +100,22 @@ sub show_window {
 
     my $text = '';
     if ( ClamTk::Prefs->get_preference( 'Update' ) eq 'shared' ) {
-        $text = _( 'You are configured to automatically receive updates' );
+        my $label = Gtk3::Label->new;
+        $label->set_text(
+            _( 'You are configured to automatically receive updates' ) );
+        $infobar->get_content_area()->add( $label );
     } else {
         $text = _( 'Check for updates' );
-        $infobar->add_button( 'gtk-ok', -5 );
-    }
+        $infobar->add_button( $text, -5 );
 
-    my $label = Gtk3::Label->new;
-    $label->set_text( $text );
-    $infobar->get_content_area()->add( $label );
-    #<<<
-    $infobar->signal_connect(
-        response => sub {
-                update_signatures();
-        }
-    );
-    #>>>
+        #<<<
+        $infobar->signal_connect(
+            response => sub {
+                    update_signatures();
+            }
+        );
+        #>>>
+    }
 
     $box->pack_start( Gtk3::VBox->new, TRUE, TRUE, 5 );
 
@@ -151,10 +151,15 @@ sub get_remote_TK_version {
 sub update_signatures {
     $pb->{ timer } = Glib::Timeout->add( 100, \&progress_timeout, $pb );
     $pb->show;
-    #$pb->set_show_text( TRUE );
     $pb->set_text( _( 'Please wait...' ) );
 
     my $freshclam = get_freshclam_path();
+    if ( ClamTk::Prefs->get_preference( 'Update' ) eq 'single' ) {
+        my $dbpath = ClamTk::App->get_path( 'db' ) . '/' . 'freshclam.conf';
+        if ( -e $dbpath ) {
+            $freshclam .= " --config-file=$dbpath";
+        }
+    }
 
     # The mirrors can be slow sometimes and may return/die
     # 'failed' despite that the update is still in progress.
